# /etc/profile.d/squash-fixups.sh

if [[ "${BASH_SOURCE[0]}" == "${0}" ]]; then
  echo "This script should be sourced, not executed."
  exit 1
fi

# Function to automate squashing and rebasing for commits starting with "fixup!"
squash_fixups() {
  # Ensure we are in a git repository
  if ! git rev-parse --is-inside-work-tree > /dev/null 2>&1; then
    echo "Not inside a git repository."
    return 1
  fi

  # Perform an interactive rebase with autosquash
  git rebase -i --autosquash HEAD~$(git rev-list --count HEAD)

  echo "Interactive rebase initiated to squash commits starting with 'fixup!'."
}

# Function to stage changes, commit with 'fixup!', and push
push_fixup() {
  # Ensure we are in a git repository
  if ! git rev-parse --is-inside-work-tree > /dev/null 2>&1; then
    echo "Not inside a git repository."
    return 1
  fi

  # Stage all changes, commit with 'fixup!', and push
  git add .
  git commit -m 'fixup!'
  git push

  echo "Changes staged, committed with 'fixup!', and pushed."
}

