# /etc/profile.d/sum.sh

if [[ "${BASH_SOURCE[0]}" == "${0}" ]]; then
  echo "This script should be sourced, not executed."
  exit 1
fi

# Function to generate SHA-256 hashes for .sh files in the src directory
calculate_hashes() {
  local base_dir="./src"

  # Check if the base directory exists
  if [ ! -d "$base_dir" ]; then
    echo "Base directory $base_dir does not exist."
    return 1
  fi

  # Determine the hash command to use
  local hash_cmd=""
  if command -v sha256sum >/dev/null 2>&1; then
    hash_cmd="sha256sum"
  elif command -v shasum >/dev/null 2>&1; then
    hash_cmd="shasum -a 256"
  else
    echo "Neither sha256sum nor shasum is available."
    return 1
  fi

  # Function to process the src directory
  process_directory() {
    local dir="$1"
    for file in "$dir"/*.sh; do
      # Skip if no .sh files are found
      [ -e "$file" ] || continue

      # Calculate the SHA-256 hash and save it to a .sha256 file
      $hash_cmd "$file" | awk '{ print $1 }' > "$file.sha256"
    done
  }

  # Process the src directory
  process_directory "$base_dir"

  echo "SHA-256 hashes have been saved in .sha256 files."
}

